{
  'calendar' => [
    {
      'month' => 6,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2013&month=6')}, 'URI::http' ),
      'year' => 2013
    },
    {
      'month' => 7,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2013&month=7')}, 'URI::http' ),
      'year' => 2013
    },
    {
      'month' => 8,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2013&month=8')}, 'URI::http' ),
      'year' => 2013
    },
    {
      'month' => 9,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2013&month=9')}, 'URI::http' ),
      'year' => 2013
    },
    {
      'month' => 10,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2013&month=10')}, 'URI::http' ),
      'year' => 2013
    },
    {
      'month' => 11,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2013&month=11')}, 'URI::http' ),
      'year' => 2013
    },
    {
      'month' => 12,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2013&month=12')}, 'URI::http' ),
      'year' => 2013
    },
    {
      'month' => 1,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2014&month=1')}, 'URI::http' ),
      'year' => 2014
    },
    {
      'month' => 2,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2014&month=2')}, 'URI::http' ),
      'year' => 2014
    },
    {
      'month' => 3,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2014&month=3')}, 'URI::http' ),
      'year' => 2014
    },
    {
      'month' => 4,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2014&month=4')}, 'URI::http' ),
      'year' => 2014
    },
    {
      'month' => 5,
      'year' => 2014
    },
    {
      'month' => 6,
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa&year=2014&month=6')}, 'URI::http' ),
      'year' => 2014
    }
  ],
  'games' => [
    {
      'black' => [
        {
          'name' => 'nnewgo',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=nnewgo')}, 'URI::http' )
        }
      ],
      'board_size' => 19,
      'owner' => {
        'name' => 'anazawa',
        'rank' => '1d',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa')}, 'URI::http' )
      },
      'result' => 'Unfinished',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2014/5/19/anazawa-3.sgf')}, 'URI::http' ),
      'start_time' => '2014-05-19T16:55Z',
      'type' => 'Review',
      'white' => [
        {
          'name' => 'anazawa',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa')}, 'URI::http' )
        }
      ]
    },
    {
      'black' => [
        {
          'name' => 'nnewgo',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=nnewgo')}, 'URI::http' )
        }
      ],
      'board_size' => 19,
      'result' => 'W+15.5',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2014/5/19/anazawa-nnewgo.sgf')}, 'URI::http' ),
      'start_time' => '2014-05-19T16:04Z',
      'type' => 'Ranked',
      'white' => [
        {
          'name' => 'anazawa',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa')}, 'URI::http' )
        }
      ]
    },
    {
      'black' => [
        {
          'name' => 'ysw',
          'rank' => '3k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=ysw')}, 'URI::http' )
        }
      ],
      'board_size' => 19,
      'handicap' => 2,
      'result' => 'W+10.5',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2014/5/19/anazawa-ysw.sgf')}, 'URI::http' ),
      'start_time' => '2014-05-19T13:20Z',
      'type' => 'Ranked',
      'white' => [
        {
          'name' => 'anazawa',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa')}, 'URI::http' )
        }
      ]
    },
    {
      'black' => [
        {
          'name' => 'riki77jr',
          'rank' => '5k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=riki77jr')}, 'URI::http' )
        }
      ],
      'board_size' => 19,
      'handicap' => 4,
      'result' => 'W+21.5',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2014/5/19/anazawa-riki77jr.sgf')}, 'URI::http' ),
      'start_time' => '2014-05-19T12:17Z',
      'type' => 'Ranked',
      'white' => [
        {
          'name' => 'anazawa',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa')}, 'URI::http' )
        }
      ]
    },
    {
      'black' => [
        {
          'name' => 'anazawa',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=anazawa')}, 'URI::http' )
        }
      ],
      'board_size' => 19,
      'result' => 'B+Resign',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2014/5/16/Sushiman-anazawa.sgf')}, 'URI::http' ),
      'start_time' => '2014-05-16T18:07Z',
      'type' => 'Ranked',
      'white' => [
        {
          'name' => 'Sushiman',
          'rank' => '1k',
          'uri' => bless( do{\(my $o = 'http://www.gokgs.com/gameArchives.jsp?user=Sushiman')}, 'URI::http' )
        }
      ]
    }
  ],
  'tgz_uri' => bless( do{\(my $o = 'http://www.gokgs.com/servlet/archives/en_US/anazawa-2014-5.tar.gz')}, 'URI::http' ),
  'zip_uri' => bless( do{\(my $o = 'http://www.gokgs.com/servlet/archives/en_US/anazawa-2014-5.zip')}, 'URI::http' )
}
