{
  'byes' => [
    {
      'name' => 'AyaMC',
      'rank' => '2k',
      'type' => 'System'
    }
  ],
  'games' => [
    {
      'black' => {
        'name' => 'Orego',
        'rank' => '8k'
      },
      'board_size' => 9,
      'result' => 'B+Forfeit',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2009/12/6/break9-Orego.sgf')}, 'URI::http' ),
      'start_time' => '2009-12-06T08:00Z',
      'white' => {
        'name' => 'break9',
        'rank' => '-'
      }
    },
    {
      'black' => {
        'name' => 'valkyria',
        'rank' => '-'
      },
      'board_size' => 9,
      'result' => 'W+Time',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2009/12/6/CzechBot-valkyria.sgf')}, 'URI::http' ),
      'start_time' => '2009-12-06T08:00Z',
      'white' => {
        'name' => 'CzechBot',
        'rank' => '2k'
      }
    },
    {
      'black' => {
        'name' => 'Zengg9',
        'rank' => '-'
      },
      'board_size' => 9,
      'result' => 'B+Resign',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2009/12/6/gomorra9-Zengg9.sgf')}, 'URI::http' ),
      'start_time' => '2009-12-06T08:00Z',
      'white' => {
        'name' => 'gomorra9',
        'rank' => '-'
      }
    },
    {
      'black' => {
        'name' => 'SimpleBot',
        'rank' => '18k'
      },
      'board_size' => 9,
      'result' => 'B+73.5',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2009/12/6/IdiotBot-SimpleBot.sgf')}, 'URI::http' ),
      'start_time' => '2009-12-06T08:00Z',
      'white' => {
        'name' => 'IdiotBot',
        'rank' => '29k'
      }
    },
    {
      'black' => {
        'name' => 'ManyFaces2',
        'rank' => '2k'
      },
      'board_size' => 9,
      'result' => 'W+Forfeit',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2009/12/6/kiseki-ManyFaces2.sgf')}, 'URI::http' ),
      'start_time' => '2009-12-06T08:00Z',
      'white' => {
        'name' => 'kiseki',
        'rank' => '-'
      }
    },
    {
      'black' => {
        'name' => 'Fuego',
        'rank' => '2k'
      },
      'board_size' => 9,
      'result' => 'B+Resign',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2009/12/6/pachi-Fuego.sgf')}, 'URI::http' ),
      'start_time' => '2009-12-06T08:00Z',
      'white' => {
        'name' => 'pachi',
        'rank' => '-'
      }
    },
    {
      'black' => {
        'name' => 'PNUGo',
        'rank' => '-'
      },
      'board_size' => 9,
      'result' => 'B+Resign',
      'sgf_uri' => bless( do{\(my $o = 'http://files.gokgs.com/games/2009/12/6/WeakBot50k-PNUGo.sgf')}, 'URI::http' ),
      'start_time' => '2009-12-06T08:00Z',
      'white' => {
        'name' => 'WeakBot50k',
        'rank' => '21k'
      }
    }
  ],
  'links' => {
    'entrants' => [
      {
        'sort_by' => 'name',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=n&id=488')}, 'URI::http' )
      },
      {
        'sort_by' => 'result',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournEntrants.jsp?sort=s&id=488')}, 'URI::http' )
      }
    ],
    'rounds' => [
      {
        'end_time' => '2009-12-06T08:20Z',
        'round' => 1,
        'start_time' => '2009-12-06T08:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=1')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T08:40Z',
        'round' => 2,
        'start_time' => '2009-12-06T08:20Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=2')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T09:00Z',
        'round' => 3,
        'start_time' => '2009-12-06T08:40Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=3')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T09:20Z',
        'round' => 4,
        'start_time' => '2009-12-06T09:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=4')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T09:40Z',
        'round' => 5,
        'start_time' => '2009-12-06T09:20Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=5')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T10:00Z',
        'round' => 6,
        'start_time' => '2009-12-06T09:40Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=6')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T10:20Z',
        'round' => 7,
        'start_time' => '2009-12-06T10:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=7')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T10:40Z',
        'round' => 8,
        'start_time' => '2009-12-06T10:20Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=8')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T11:00Z',
        'round' => 9,
        'start_time' => '2009-12-06T10:40Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=9')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T11:20Z',
        'round' => 10,
        'start_time' => '2009-12-06T11:00Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=10')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T11:40Z',
        'round' => 11,
        'start_time' => '2009-12-06T11:20Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=11')}, 'URI::http' )
      },
      {
        'end_time' => '2009-12-06T12:00Z',
        'round' => 12,
        'start_time' => '2009-12-06T11:40Z',
        'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=12')}, 'URI::http' )
      }
    ]
  },
  'name' => 'December 2009 KGS bot tournament',
  'next_round_uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournGames.jsp?id=488&round=2')}, 'URI::http' ),
  'round' => 1
}
