{
  'tournaments' => [
    {
      'name' => 'December KGS+ Blitz Tournament, American daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=856')}, 'URI::http' )
    },
    {
      'name' => 'December KGS+ Blitz Tournament, American daytime 3k and under division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=855')}, 'URI::http' )
    },
    {
      'name' => 'December KGS+ Blitz Tournament, Asian/European daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=854')}, 'URI::http' )
    },
    {
      'name' => 'December KGS+ Blitz Tournament, Asian/European daytime 3k and under division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=853')}, 'URI::http' )
    },
    {
      'name' => 'December 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=857')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Semifinals, Part 2',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=852')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Semifinals, Part 1',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=851')}, 'URI::http' )
    },
    {
      'name' => 'November 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=848')}, 'URI::http' )
    },
    {
      'name' => 'November KGS+ Tournament, Daytime 2 ',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=847')}, 'URI::http' )
    },
    {
      'name' => 'November KGS+ Tournament, Daytime 1 ',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=846')}, 'URI::http' )
    },
    {
      'name' => 'October KGS+ Tournament, American Daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=844')}, 'URI::http' )
    },
    {
      'name' => 'October KGS+ Tournament, American Daytime 2k and under Handicap division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=843')}, 'URI::http' )
    },
    {
      'name' => 'October KGS+ Tournament, Asian/European Daytime 2k and under Handicap division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=841')}, 'URI::http' )
    },
    {
      'name' => 'October KGS+ Tournament, Asian/European Daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=842')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier October 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=845')}, 'URI::http' )
    },
    {
      'name' => 'October 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=837')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier September 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=836')}, 'URI::http' )
    },
    {
      'name' => 'September Iron Man Tournament: Kyu Handicap Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=833')}, 'URI::http' )
    },
    {
      'name' => 'September Iron Man Tournament: Open Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=834')}, 'URI::http' )
    },
    {
      'name' => 'September 2013 SLOW bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=835')}, 'URI::http' )
    },
    {
      'name' => 'August 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=832')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier August 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=831')}, 'URI::http' )
    },
    {
      'name' => 'August KGS+ Tournament, American Daytime',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=828')}, 'URI::http' )
    },
    {
      'name' => 'August KGS+ Tournament, Asian/European Daytime',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=827')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier July 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=826')}, 'URI::http' )
    },
    {
      'name' => 'July KGS+ Crazy Boardsizes tournament : 23x23 American Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=824')}, 'URI::http' )
    },
    {
      'name' => 'July KGS+ Crazy Boardsizes tournament : 23x23 Asian/European Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=823')}, 'URI::http' )
    },
    {
      'name' => 'July KGS+ Crazy Boardsizes tournament : 17x17 American Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=822')}, 'URI::http' )
    },
    {
      'name' => 'July KGS+ Crazy Boardsizes tournament : 35x35 the Insane Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=825')}, 'URI::http' )
    },
    {
      'name' => 'July KGS+ Crazy Boardsizes tournament : 17x17 Asian/European Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=821')}, 'URI::http' )
    },
    {
      'name' => 'July 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=815')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier June 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=814')}, 'URI::http' )
    },
    {
      'name' => 'June KGS+ Tournament, American Daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=813')}, 'URI::http' )
    },
    {
      'name' => 'June KGS+ Tournament, American Daytime 4k and under division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=812')}, 'URI::http' )
    },
    {
      'name' => 'June KGS+ Tournament, Asian/European Daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=811')}, 'URI::http' )
    },
    {
      'name' => 'June KGS+ Tournament, Asian/European Daytime 4k and under division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=810')}, 'URI::http' )
    },
    {
      'name' => 'June 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=809')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier May 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=808')}, 'URI::http' )
    },
    {
      'name' => 'May 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=807')}, 'URI::http' )
    },
    {
      'name' => 'May KGS+ Tournament, American daytime 2k and under division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=805')}, 'URI::http' )
    },
    {
      'name' => 'May KGS+ Tournament, American daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=806')}, 'URI::http' )
    },
    {
      'name' => 'May KGS+ Tournament, Asian/European daytime 2k and under division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=803')}, 'URI::http' )
    },
    {
      'name' => 'May KGS+ Tournament, Asian/European daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=804')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier April 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=802')}, 'URI::http' )
    },
    {
      'name' => 'April KGS+ Tournament, American daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=801')}, 'URI::http' )
    },
    {
      'name' => 'April KGS+ Tournament, Asian/European daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=800')}, 'URI::http' )
    },
    {
      'name' => 'April 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=799')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier March 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=797')}, 'URI::http' )
    },
    {
      'name' => 'March Iron Man Tournament: Kyu Handicap Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=795')}, 'URI::http' )
    },
    {
      'name' => 'March Iron Man Tournament: Open Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=798')}, 'URI::http' )
    },
    {
      'name' => 'March 2013 SLOW bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=794')}, 'URI::http' )
    },
    {
      'name' => 'February KGS+ Tournament, American Daytime Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=792')}, 'URI::http' )
    },
    {
      'name' => 'February KGS+ Tournament, Asian/European Daytime Division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=791')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier February 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=790')}, 'URI::http' )
    },
    {
      'name' => 'February 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=789')}, 'URI::http' )
    },
    {
      'name' => 'January KGS+ Tournament, American/European daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=786')}, 'URI::http' )
    },
    {
      'name' => 'January KGS+ Tournament, American/European daytime 2k and weaker division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=785')}, 'URI::http' )
    },
    {
      'name' => 'January KGS+ Tournament, Asian/European daytime 2k and weaker division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=783')}, 'URI::http' )
    },
    {
      'name' => 'January KGS+ Tournament, Asian/European daytime Open division',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=784')}, 'URI::http' )
    },
    {
      'name' => 'KGS Meijin Qualifier January 2013',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=788')}, 'URI::http' )
    },
    {
      'name' => 'January 2013 KGS bot tournament',
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournInfo.jsp?id=787')}, 'URI::http' )
    }
  ],
  'year_index' => [
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2001')}, 'URI::http' ),
      'year' => 2001
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2002')}, 'URI::http' ),
      'year' => 2002
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2003')}, 'URI::http' ),
      'year' => 2003
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2004')}, 'URI::http' ),
      'year' => 2004
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2005')}, 'URI::http' ),
      'year' => 2005
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2006')}, 'URI::http' ),
      'year' => 2006
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2007')}, 'URI::http' ),
      'year' => 2007
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2008')}, 'URI::http' ),
      'year' => 2008
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2009')}, 'URI::http' ),
      'year' => 2009
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2010')}, 'URI::http' ),
      'year' => 2010
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2011')}, 'URI::http' ),
      'year' => 2011
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2012')}, 'URI::http' ),
      'year' => 2012
    },
    {
      'year' => 2013
    },
    {
      'uri' => bless( do{\(my $o = 'http://www.gokgs.com/tournList.jsp?year=2014')}, 'URI::http' ),
      'year' => 2014
    }
  ]
}
