use strict;
use warnings;
use Test::More tests => 7;

use_ok 'WWW::GoKGS::Scraper::GameArchives';
use_ok 'WWW::GoKGS::Scraper::Top100';
use_ok 'WWW::GoKGS::Scraper::TournList';
use_ok 'WWW::GoKGS::Scraper::TournInfo';
use_ok 'WWW::GoKGS::Scraper::TournEntrants';
use_ok 'WWW::GoKGS::Scraper::TournGames';

use_ok 'WWW::GoKGS';
